SystemOrganization addCategory: #'OCMS-Kernel'!

Object subclass: #Comment
	instanceVariableNames: 'id login user dateAndTime text'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!Comment commentStamp: 'HAS 4/30/2013 20:35' prior: 0!
I represent comments made by users regarding the courseware.!

!Comment methodsFor: 'accessing' stamp: 'has 6/23/2013 08:00'!
createId
	id:= self hash.! !

!Comment methodsFor: 'accessing' stamp: 'HAS 4/30/2013 20:09'!
dateAndTime

	^ dateAndTime! !

!Comment methodsFor: 'accessing' stamp: 'HAS 4/30/2013 20:09'!
dateAndTime: aDateAndTime

	dateAndTime := aDateAndTime! !

!Comment methodsFor: 'comparing' stamp: 'has 6/24/2013 06:45'!
hash
	(self user isNil)
		ifTrue:[self user: ''].
	(self dateAndTime isNil)
		ifTrue:[self dateAndTime: ''].
	(self text isNil)
		ifTrue: [self text: ''].
	^[self user login, '|',  self dateAndTime, '|', self text] value hash.! !

!Comment methodsFor: 'accessing' stamp: 'has 6/23/2013 08:00'!
id
	^id! !

!Comment methodsFor: 'testing' stamp: 'has 6/1/2013 23:17'!
isComment
	^ true.! !

!Comment methodsFor: 'accessing' stamp: 'has 6/24/2013 15:26'!
login
	^user login.! !

!Comment methodsFor: 'accessing' stamp: 'HAS 4/30/2013 20:08'!
text

	^ text! !

!Comment methodsFor: 'accessing' stamp: 'HAS 4/30/2013 20:08'!
text: aText

	text := aText! !

!Comment methodsFor: 'accessing' stamp: 'has 6/23/2013 00:22'!
user

	^user! !

!Comment methodsFor: 'accessing' stamp: 'HAS 4/30/2013 20:07'!
user: anUser

	user := anUser! !

Object subclass: #Course
	instanceVariableNames: 'description category group creationDateTime'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!Course commentStamp: 'oda 5/1/2013 20:50' prior: 0!
Not implemented yet.!

!Course methodsFor: 'accessing' stamp: 'oda 6/24/2013 22:01'!
category
	^ category! !

!Course methodsFor: 'accessing' stamp: 'oda 6/24/2013 22:02'!
category: aString
	category := aString! !

!Course methodsFor: 'accessing' stamp: 'oda 6/24/2013 22:06'!
creationDateTime
	^ creationDateTime! !

!Course methodsFor: 'accessing' stamp: 'oda 6/24/2013 22:06'!
creationDateTime: aDateTime
	creationDateTime := aDateTime.! !

!Course methodsFor: 'accessing' stamp: 'has 6/27/2013 19:46'!
description
	^ description! !

!Course methodsFor: 'accessing' stamp: 'has 6/27/2013 19:46'!
description: aDescription
	description:=aDescription.! !

!Course methodsFor: 'accessing' stamp: 'has 6/28/2013 17:18'!
getAllCourseModerators
	"i return all moderators from the groups related to the course"
	| listModerator |
	listModerator:= OrderedCollection new.
	self group do:[:each | listModerator addAll: each getAllGroupModerators].
	^listModerator.! !

!Course methodsFor: 'accessing' stamp: 'oda 6/24/2013 22:02'!
group
	^ group
	! !

!Course methodsFor: 'accessing' stamp: 'oda 6/24/2013 22:10'!
group: aCollection
	group := aCollection
	! !

!Course methodsFor: 'creating' stamp: 'oda 6/26/2013 22:15'!
includeGroup: aGroup
	"Includes aGroup in this course."
	group add: aGroup.
	aGroup course: self! !

!Course methodsFor: 'initialize-release' stamp: 'oda 6/24/2013 22:29'!
initialize
	group := OrderedCollection new! !

!Course methodsFor: 'testing' stamp: 'oda 6/24/2013 23:06'!
isCourse
	^ true! !

!Course methodsFor: 'updating' stamp: 'oda 6/26/2013 21:17'!
removeGroup: aGroup
	"Removes aGroup from this course."
	group remove: aGroup.
	aGroup course: nil! !

!Course methodsFor: 'accessing' stamp: 'has 6/30/2013 13:48'!
searchAllCourses
	"i return a collection of all courses"
	| courseList courseOrdered |
	
	courseList := OrderedCollection new.
	courseList := Courses getAll.
	courseOrdered:= OrderedCollection new.
	courseList do:[:each | courseOrdered add: each ].
	^ courseOrdered.! !

Object subclass: #CourseManager
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!CourseManager commentStamp: '<historical>' prior: 0!
Store the tags used to classify courseware.

	name <String>							Name of the tag.
	relatedTag <OrderedCollection of: Tag>		Contains the related tags.!

!CourseManager methodsFor: 'testing' stamp: 'oda 6/30/2013 17:58'!
courseExists: aCourse
	"I check if course already exists"
	| courseTemp |
	courseTemp:=Courses searchByDescription: aCourse description.
	^courseTemp notNil.! !

!CourseManager methodsFor: 'creating' stamp: 'oda 6/30/2013 17:44'!
includeCourse: aCourse
	"i include a Course in database"
	| notification |
	notification := OCMSNotificationManager new.

	self validateCourse: aCourse.

	Courses add: aCourse.
	notification newCourseNotification: aCourse! !

!CourseManager methodsFor: 'updating' stamp: 'has 7/2/2013 09:46'!
removeCourse: aCourse
	"i remove a Course"
	| notification |
	aCourse isCourse.
	notification := OCMSNotificationManager new.
	notification removeCourseNotification: aCourse.
	Courses removeCascade: aCourse.! !

!CourseManager methodsFor: 'accessing' stamp: 'has 6/30/2013 12:40'!
searchAllCourses
	"i return a collection of courses that contains the typed word"
	| courseList |
	
	courseList := OrderedCollection new.
	courseList := Courses getAll.
	^ courseList.! !

!CourseManager methodsFor: 'accessing' stamp: 'has 6/26/2013 07:10'!
searchCourse: aCourse
	"i return a collection of courses that contains the typed word"
	| courseList |
	
	courseList := OrderedCollection new.
	courseList := Courses searchByName: aCourse.
	^ courseList.! !

!CourseManager methodsFor: 'accessing' stamp: 'has 7/1/2013 19:55'!
searchCourseByGroup: aCourse
	"i return a collection of courses related to the group"
	| courseList |
	
	courseList := OrderedCollection new.
	courseList := Courses searchAllCourses.
	^ courseList.! !

!CourseManager methodsFor: 'updating' stamp: 'oda 7/1/2013 02:48'!
updateCourse: aCourse
	"i update a Course"
	self validateCourseToBeUpdated: aCourse.  
	Courses update: aCourse.! !

!CourseManager methodsFor: 'creating' stamp: 'oda 7/1/2013 02:48'!
validateCourse: aCourse
	self validateCourseToBeUpdated: aCourse.
	
	(self courseExists: aCourse)
		ifTrue: [ self error: 'This course name is already used' ].! !

!CourseManager methodsFor: 'creating' stamp: 'oda 7/1/2013 02:47'!
validateCourseToBeUpdated: aCourse
	aCourse isCourse.
	OCMSUtilities ifNotAlphanum: aCourse description raiseError: 'Invalid name'.
! !

Object subclass: #Courseware
	instanceVariableNames: 'id title description summary coursewareType owner reference tag course author creationDateTime modificationDateTime cataloguingData license size comment score usersWithWritePermission isEnabled downloadCounter file'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!Courseware commentStamp: 'HAS 4/28/2013 17:10' prior: 0!
Contains information about courseware

Instance variables:
	id <Long>										Unique identification
	title <String>										Title
	description <String>								Description
	summary <String>								A summary of the courseware's contents (optional)
	coursewareType <Symbol>						Type of courseware getting from CoursewareTypeSet class variable
	owner <User>									User that upload the courseware	
	reference <String>								Information about authors, journal, url, related courseware,...
	tag <List of: Tag>								A sorted list of tags related
	classification <List of: Discipline>					Disciplines/Areas related to the courseware
	author <List of: String>							Author(s) of the courseare in a ordered list
	creationDateTime <DateAndTime>					Date and time in which the courseware was uploaded
	modificationDateTime <DateAndTime>				Date and time of the last modification of the courseware
	cataloguingData <String>							Information about cataloguing data.
	license <LicenseType>							Type of license described in LicenseTypeSet class variable
	size <Integer>									Size of the courseware in K bytes
	comment <List of: Comment>						A list of comments of the courseware
	score <Map of: User and Float>					A map representing the score atributed by each user
	permission <Map of: User and PermissionType>	A map associating user and type of permission that they have
	enabled <Boolean>								A flag that indicates if the courseware is enable or not
	downloadCounter <Integer>						Number of downloads of the courseware
	file <File>										File name and extension of courseware!

!Courseware methodsFor: 'accessing' stamp: 'has 6/1/2013 16:57'!
author
	"I return an OrderedCollection of strings containing the name of the authors"

	^ author! !

!Courseware methodsFor: 'accessing' stamp: 'has 6/1/2013 17:01'!
author: anOrderedCollectionString
	"I receive an OrderedCollection of String with the author's name"
	
	author := anOrderedCollectionString! !

!Courseware methodsFor: 'testing' stamp: 'has 6/30/2013 13:54'!
authorExists: anAuthor
	tag do:[:each | (each = anAuthor)
						ifTrue:[^true]].
	^false.! !

!Courseware methodsFor: 'accessing' stamp: 'has 6/29/2013 17:59'!
authorString
	| stringAuthor |
	(self author size = 1)
		ifTrue:[stringAuthor:= self author at: 1].
	(self author size > 1)
		ifTrue:[	stringAuthor:= self author at: 1.
				2 to: self author size do:[:each | stringAuthor:=stringAuthor,', ',(self author at: each)].].
	^stringAuthor.! !

!Courseware methodsFor: 'calculating' stamp: 'has 7/2/2013 06:43'!
calculateRatingScore
	"I calculate the rating score from the scores gave by the users"
	| rating scoreDictionary |
	
	rating := 0.
	scoreDictionary := self score.
	scoreDictionary valuesDo: [:each | rating := rating + each].
	(scoreDictionary size > 0)
		ifTrue:[rating := rating / (scoreDictionary size asFloat)].
	^ rating.! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 16:58'!
cataloguingData
	^ cataloguingData! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 16:58'!
cataloguingData: aString
	cataloguingData := aString! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:01'!
comment
	^ comment! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/30/2013 23:14'!
comment: anOrderedCollectionComment
	comment := anOrderedCollectionComment! !

!Courseware methodsFor: 'accessing' stamp: 'has 5/29/2013 00:20'!
course
	^ course! !

!Courseware methodsFor: 'accessing' stamp: 'has 5/29/2013 00:20'!
course: aSortedCollectionCourse
	course := aSortedCollectionCourse! !

!Courseware methodsFor: 'testing' stamp: 'has 6/30/2013 11:58'!
courseExists: aCourse
	course do:[:each | (each description = aCourse description)
						ifTrue:[^true]].
	^false.! !

!Courseware methodsFor: 'accessing' stamp: 'has 6/29/2013 17:54'!
courseString
	| stringCourse |
	(self course size = 1)
		ifTrue:[stringCourse:= (self course at: 1) description].
	(self course size > 1)
		ifTrue:[	stringCourse:= (self course at: 1) description.
				2 to: self course size do:[:each | stringCourse:=stringCourse,', ',(self course at: each) description].].
	^stringCourse.! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/27/2013 15:22'!
coursewareType
	^ coursewareType! !

!Courseware methodsFor: 'accessing' stamp: 'has 6/24/2013 09:56'!
coursewareType: aSymbol
	(CoursewareType coursewareTypeList includes: aSymbol)
		ifTrue:[coursewareType := aSymbol]
		ifFalse:[self error: 'This CoursewareType does not exist']! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 16:57'!
creationDateTime
	^ creationDateTime! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 16:57'!
creationDateTime: aDateAndTime
	creationDateTime := aDateAndTime! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/27/2013 15:18'!
description
	^ description! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/27/2013 15:19'!
description: aString
	description := aString! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:08'!
downloadCounter
	^ downloadCounter! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:08'!
downloadCounter: anInteger
	downloadCounter := anInteger! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:09'!
file
	^ file! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:09'!
file: aFile
	file := aFile! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/27/2013 12:18'!
id
	^ id! !

!Courseware methodsFor: 'accessing' stamp: 'has 6/2/2013 17:42'!
id: anInteger
	(anInteger isInteger)
		ifTrue:[id := anInteger]
		ifFalse:[self error: 'The value must be an integer']! !

!Courseware methodsFor: 'initialize' stamp: 'has 7/1/2013 10:15'!
initialize
	self downloadCounter: 0.
	self isEnabled: true.
	self usersWithWritePermission: OrderedCollection new.
	self comment: OrderedCollection new.
	self tag: OrderedCollection new.
	self course: OrderedCollection new.
	self author: OrderedCollection new.
	self score: Dictionary new.
	self size: 0.! !

!Courseware methodsFor: 'testing' stamp: 'HAS 4/28/2013 19:54'!
isCourseware
	^true! !

!Courseware methodsFor: 'accessing' stamp: 'has 5/12/2013 08:07'!
isEnabled
	^ isEnabled! !

!Courseware methodsFor: 'accessing' stamp: 'has 5/12/2013 08:07'!
isEnabled: aBoolean
	isEnabled := aBoolean! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 16:59'!
license
	^ license! !

!Courseware methodsFor: 'accessing' stamp: 'has 6/30/2013 15:49'!
license: aSymbol
	(LicenseType licenseTypeList includes: aSymbol)
		ifTrue:[license := aSymbol]
		ifFalse:[self error: 'This LicenseType does not exist']! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/29/2013 19:50'!
modificationDateTime
	^ modificationDateTime! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/29/2013 19:50'!
modificationDateTime: aDateAndTime
	modificationDateTime := aDateAndTime! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 01:09'!
owner
	^ owner! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 07:44'!
owner: aUser
	owner := aUser! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 07:58'!
reference
	^ reference! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 07:59'!
reference: aString
	reference := aString! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:01'!
score
	^ score! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:05'!
score: aMapOfUserAndFloat
	score := aMapOfUserAndFloat! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:00'!
size
	^ size! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:00'!
size: aFloat
	size := aFloat! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/27/2013 15:20'!
summary
	^ summary! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/27/2013 15:19'!
summary: aString
	summary := aString! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 16:40'!
tag
	^tag! !

!Courseware methodsFor: 'accessing' stamp: 'has 6/2/2013 10:52'!
tag: anOrderedCollectionTag
	
	(anOrderedCollectionTag isMemberOf: OrderedCollection)
		ifTrue: [tag := anOrderedCollectionTag]
		ifFalse: [self error: 'This method must receives an OrderedCollection of Tag']
! !

!Courseware methodsFor: 'testing' stamp: 'has 6/30/2013 11:04'!
tagExists: aTagName
	tag do:[:each | (each label = aTagName)
						ifTrue:[^true]].
	^false.! !

!Courseware methodsFor: 'accessing' stamp: 'has 6/29/2013 17:51'!
tagString
	| stringTag |
	(self tag size = 1)
		ifTrue:[stringTag:= (self tag at: 1) label].
	(self tag size > 1)
		ifTrue:[	stringTag:= (self tag at: 1) label.
				2 to: self tag size do:[:each | stringTag:=stringTag,', ',(self tag at: each) label].].
	^stringTag.! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/27/2013 14:00'!
title
	^ title! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:38'!
title: anString
	title := anString! !

!Courseware methodsFor: 'accessing' stamp: 'has 5/29/2013 08:01'!
usersWithWritePermission
	^ usersWithWritePermission! !

!Courseware methodsFor: 'accessing' stamp: 'has 5/29/2013 08:02'!
usersWithWritePermission: anUserOrderedCollection
	usersWithWritePermission := anUserOrderedCollection! !

Object subclass: #CoursewareManager
	instanceVariableNames: 'courseware coursewareList'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!CoursewareManager commentStamp: 'HAS 4/29/2013 10:31' prior: 0!
This class manages coursewares, which include methods to search, edit and classify a courseware.

	courseware <Courseware>	Represent a courseware!

!CoursewareManager methodsFor: 'updating' stamp: 'has 6/24/2013 07:14'!
blockCourseware: aCourseware user: anUser
	"I block the couseware if the user has the permissions to do this"
	
	| notification |
	anUser isUser.
	aCourseware isCourseware.
	notification := OCMSNotificationManager new.
	
	(anUser isAdmin or: (self isOwner: anUser ofCourseware: aCourseware) or: (self isProfessor: anUser atCourseware: aCourseware))
		ifTrue:[(aCourseware isEnabled)
				ifTrue:[aCourseware isEnabled: false]
				ifFalse:[self error: 'This courseware was already blocked.'].
				]
		ifFalse:[self error: 'You do not have permission to block this courseware.'].
	self updateCourseware: aCourseware.
	notification blockCoursewareNotification: aCourseware.
	^ aCourseware! !

!CoursewareManager methodsFor: 'calculating' stamp: 'has 7/1/2013 10:01'!
calculateRatingScore: aCourseware
	"I calculate the rating score from the scores gave by the users"
	| rating scoreDictionary |
	
	aCourseware isCourseware.
	rating := 0.
	scoreDictionary := aCourseware score.
	scoreDictionary valuesDo: [:each | rating := rating + each].
	(scoreDictionary size > 0)
		ifTrue:[rating := rating / scoreDictionary size].
	^ rating.! !

!CoursewareManager methodsFor: 'accessing' stamp: 'HAS 4/29/2013 10:32'!
courseware
	^ courseware! !

!CoursewareManager methodsFor: 'accessing' stamp: 'HAS 4/29/2013 10:33'!
courseware: aCourseware
	courseware := aCourseware! !

!CoursewareManager methodsFor: 'testing' stamp: 'has 6/24/2013 07:14'!
hasWritePermission: anUser withCourseware: aCourseware
	"i check if user has write permission to the courseware"
	
	anUser isUser.
	aCourseware isCourseware.
	
	(aCourseware usersWithWritePermission includes: anUser)
		ifTrue:[^ true].
	^ false.! !

!CoursewareManager methodsFor: 'updating' stamp: 'has 6/24/2013 09:10'!
includeAuthor: anAuthor ofCourseware:aCourseware 
	"i include a an author in courseware"
	
	| authorCollection |
	
	aCourseware isCourseware.
		
	authorCollection := aCourseware comment.
	authorCollection add: anAuthor.
	aCourseware author: authorCollection.
	self updateCourseware: aCourseware.! !

!CoursewareManager methodsFor: 'updating' stamp: 'has 6/29/2013 20:32'!
includeComment: aCourseware comment: aComment
	"i include a comment of an user in courseware"
	
	| commentCollection notification |
	
	aCourseware isCourseware.
	aComment isComment.
	notification := OCMSNotificationManager new.
		
	commentCollection := aCourseware comment.
	aComment createId.
	commentCollection add: aComment.
	aCourseware comment: commentCollection.
	self updateCourseware: aCourseware.
	Comments add: aComment.
	notification newCommentNotification: aComment ofCourseware: aCourseware.! !

!CoursewareManager methodsFor: 'creating' stamp: 'has 7/1/2013 11:41'!
includeCourseware: aCourseware
	"I include a new courseware"
	| notification |
	aCourseware isCourseware.
	aCourseware creationDateTime: DateAndTime now.
	aCourseware modificationDateTime: nil.
	notification := OCMSNotificationManager new.
	Coursewares add: aCourseware.
	notification newCoursewareNotification: aCourseware.! !

!CoursewareManager methodsFor: 'creating' stamp: 'has 6/24/2013 07:45'!
includeCourseware: aTitle withDescription: aDescription withSummary: aSummary withCoursewareType: aCoursewareType withReference: aReference withOwner: anOwner withTag: aTagList withCourse: aCourseList withAuthor: anAuthorList withCataloguingData: aCataloguingData withLicense: aLicenseType withSize: aSize withFile: aFile
	"I include a new courseware"
	| coursewareTemp |
	coursewareTemp := Courseware new.
	coursewareTemp title: aTitle.
	coursewareTemp description: aDescription.
	coursewareTemp summary: aSummary.
	coursewareTemp coursewareType: aCoursewareType.
	coursewareTemp owner: anOwner.
	coursewareTemp reference: aReference.
	coursewareTemp tag: aTagList.
	coursewareTemp course: aCourseList.
	coursewareTemp author: anAuthorList.
	coursewareTemp creationDateTime: DateAndTime now.
	coursewareTemp modificationDateTime: nil.
	coursewareTemp cataloguingData: aCataloguingData.
	coursewareTemp license: aLicenseType.
	coursewareTemp size: aSize.
	coursewareTemp isEnabled: true.
	coursewareTemp downloadCounter: 0.
	coursewareTemp file: aFile.
	self includeCourseware: coursewareTemp.! !

!CoursewareManager methodsFor: 'updating' stamp: 'has 6/24/2013 07:16'!
includeOrUpdateCoursewareScore: aCourseware ofUser: anUser withScore: aScore
	"include a score for the courseware gave by an User"

	| scoreDictionary login notification |

	aCourseware isCourseware.
	anUser isUser.
	aScore isNumber.
	notification := OCMSNotificationManager new.
	login := anUser login.
	scoreDictionary := aCourseware score.
	scoreDictionary at: login put: aScore.
	aCourseware score: scoreDictionary.

	self updateCourseware: aCourseware.
	notification scoreNotification: anUser ofCourseware: aCourseware.
	^aCourseware! !

!CoursewareManager methodsFor: 'updating' stamp: 'has 6/24/2013 07:17'!
includeUserWritePermission: aCourseware user: anUser
	"i include permissions to user write coursewares"
	
	| userSession notification |
	
	aCourseware isCourseware.
	anUser isUser.
	notification := OCMSNotificationManager new.
	"userSession must be an user in a System class"
	"userSession := System session."
	userSession := aCourseware owner.
	(self isOwner: anUser ofCourseware: aCourseware)
		ifTrue:[self error: 'The owner already has write permissions.'].
	(userSession isAdmin or: (self isOwner: userSession ofCourseware: aCourseware) or: (self isProfessor: userSession atCourseware: aCourseware))
		ifTrue:[
				((self hasWritePermission: anUser withCourseware: aCourseware) not)
					ifTrue:[aCourseware usersWithWritePermission add: anUser.
						^aCourseware]
					ifFalse:[self error: 'This user already has permission to the courseware']
				]
		ifFalse:[self error: 'You do not have permission to do this'].
		
	self updateCourseware: aCourseware.
	notification includeWritePermissionNotification: anUser ofCourseware: aCourseware.! !

!CoursewareManager methodsFor: 'updating' stamp: 'has 6/24/2013 07:17'!
incrementDownloadCounter: aCourseware

	"increase the number of downloads of a courseware"
	
	aCourseware isCourseware.
	
	aCourseware downloadCounter: aCourseware downloadCounter + 1.
	self updateCourseware: aCourseware.
	^ aCourseware.! !

!CoursewareManager methodsFor: 'testing' stamp: 'has 6/28/2013 14:06'!
isModerator: anUser atCourseware: aCourseware
	"i check if the user is moderator at least one course of the courseware"
	
	| courseList groupList |
	anUser isUser.
	aCourseware isCourseware.

	courseList := aCourseware course.
	1 to: courseList size do: [:each | groupList := (courseList at: each) group.
									1 to: groupList size do:[:eachgroup | ((anUser roleAtGroup: (groupList at: eachgroup)) = UserType moderator)
										ifTrue:[^ true]]].
	^ false.! !

!CoursewareManager methodsFor: 'testing' stamp: 'has 6/24/2013 07:17'!
isOwner: anUser ofCourseware: aCourseware
	"i check if user is the owner of the courseware"
	
	aCourseware isCourseware.
	anUser isUser.
	
	(aCourseware owner = anUser)
		ifTrue:[^ true].
	^ false.! !

!CoursewareManager methodsFor: 'testing' stamp: 'has 6/24/2013 07:19'!
isProfessor: anUser atCourseware: aCourseware
	"i check if the user is professor at least one course of the courseware"
	
	[| courseList |
	anUser isUser.
	aCourseware isCourseware.

	courseList := aCourseware course.
	1 to: courseList size do: [:each | ((anUser roleAtCourse: (courseList at: each)) = UserType professor)
										ifTrue:[^ true]].
	^ false.]
	on: Exception
	do: [:sig | sig return: nil]! !

!CoursewareManager methodsFor: 'updating' stamp: 'has 7/2/2013 09:47'!
removeCourseware: aCourseware
	"i remove a Courseware"
	| notification |
	aCourseware isCourseware.
	notification := OCMSNotificationManager new.
	notification removeCoursewareNotification: aCourseware.
	Coursewares removeCascade: aCourseware.! !

!CoursewareManager methodsFor: 'updating' stamp: 'has 6/24/2013 07:20'!
removeUserWritePermission: aCourseware user: anUser
	"i remove permissions to user write coursewares"
	
	| userSession notification |
	"userSession must be an user in a System class"
	"userSession := System session."
	notification := OCMSNotificationManager new.
	userSession := aCourseware owner.
	(userSession isAdmin or: (self isOwner: userSession ofCourseware: aCourseware) or: (self isProfessor: userSession atCourseware: aCourseware))
		ifTrue:[
				(self hasWritePermission: anUser withCourseware: aCourseware)
					ifTrue:[aCourseware usersWithWritePermission add: anUser.
							^aCourseware]
					ifFalse:[self error: 'This user cannot has permission to the courseware']
				]
		ifFalse:[self error: 'You do not have permission to do this'].
		
	self updateCourseware: aCourseware.
	notification removeWritePermissionNotification: anUser ofCourseware: aCourseware.! !

!CoursewareManager methodsFor: 'accessing' stamp: 'has 7/1/2013 11:11'!
searchAllAuthors
	"i return all authors existing in all coursewares"
	| authorList |
	coursewareList:=self searchAllCoursewares.
	authorList:= Set new.
	coursewareList do:[:each | each author do:[:aut | authorList add: aut.]].
	^authorList.
! !

!CoursewareManager methodsFor: 'accessing' stamp: 'has 6/2/2013 10:02'!
searchAllCoursewares
	"i return an ordered collection with all coursewares"
	| coursewareList |
	
	coursewareList := OrderedCollection new.
	coursewareList := Coursewares getAll. "asOrderedCollection"
	^ coursewareList! !

!CoursewareManager methodsFor: 'accessing' stamp: 'has 5/13/2013 16:52'!
searchCoursewareByAuthor: aString
	"i return an ordered collection of the coursewares from a same author"
	| coursewareList coursewareDao|
	
	coursewareList := OrderedCollection new.
	"coursewareDao := CoursewareDAO new.
	coursewareList := cousewareDao searchCoursewareByAuthor: aString."
	^ coursewareList! !

!CoursewareManager methodsFor: 'accessing' stamp: 'has 7/2/2013 07:12'!
searchCoursewareByCourse: aCourse
	"I return a collection with coursewares that belongs to a course"
	| coursewares |
	coursewares:=Coursewares getAll select: [:each | each course = (each course select:[:ea |ea = aCourse])].
	^coursewares.! !

!CoursewareManager methodsFor: 'accessing' stamp: 'has 7/2/2013 08:15'!
searchCoursewareByGroup: aGroup
	"I return a collection with coursewares that belongs to a group"
	| coursewaresWithCourse coursewareSet |
	coursewaresWithCourse:=Coursewares getAll select: [:each | each course size > 0].
	coursewareSet := Set new.
	coursewaresWithCourse do:[:each | ((each course) 
											do:[:ec | (ec group size > 0)
														ifTrue:[((ec group) do:[:gr | (gr = aGroup)
																					ifTrue:[coursewareSet add: each].
																				] 
																)].
												]
										 )
								].
	^(coursewareSet asOrderedCollection).! !

!CoursewareManager methodsFor: 'accessing' stamp: 'has 6/2/2013 09:39'!
searchCoursewareById: anId
	"i return a courseware with the typed id"
	
	anId isInteger.
	
	self courseware: (Coursewares searchById: anId).
	^ self courseware.! !

!CoursewareManager methodsFor: 'accessing' stamp: 'has 5/13/2013 16:51'!
searchCoursewareByOwner: anUser
	"i return an ordered collection of the coursewares from a same owner"
	| coursewareList coursewareDao|
	
	coursewareList := OrderedCollection new.
	"coursewareDao := CoursewareDAO new.
	coursewareList := cousewareDao searchCoursewareByOwner: anUser."
	^ coursewareList! !

!CoursewareManager methodsFor: 'accessing' stamp: 'has 5/13/2013 16:54'!
searchCoursewareByRating: aValue
	"i return an ordered collection of the coursewares with the same rating"
	| coursewareList coursewareDao|
	
	coursewareList := OrderedCollection new.
	"coursewareDao := CoursewareDAO new.
	coursewareList := cousewareDao searchCoursewareByRating: aValue."
	^ coursewareList! !

!CoursewareManager methodsFor: 'accessing' stamp: 'has 5/13/2013 16:53'!
searchCoursewareByTag: aTag
	"i return an ordered collection of the coursewares with the same tag"
	| coursewareList coursewareDao|
	
	coursewareList := OrderedCollection new.
	"coursewareDao := CoursewareDAO new.
	coursewareList := cousewareDao searchCoursewareByTag: aTag."
	^ coursewareList! !

!CoursewareManager methodsFor: 'accessing' stamp: 'has 6/3/2013 10:44'!
searchCoursewareByTitle: aTitle
	"i return an ordered collection of coursewares with the typed title"
	| coursewareList |
	
	coursewareList := OrderedCollection new.
	coursewareList := Coursewares searchByTitle: aTitle. "asOrderedCollection."
	^ coursewareList.! !

!CoursewareManager methodsFor: 'accessing' stamp: 'has 5/13/2013 19:53'!
searchCoursewareByUser: anUser withPermission: aPermissionType
	"i return an ordered collection of the coursewares in which an user has a type of permission"
	| coursewareList coursewareDao|
	
	coursewareList := OrderedCollection new.
	"coursewareDao := CoursewareDAO new.
	coursewareList := cousewareDao searchCoursewareByUser: anUser withPermission: aPermissionType."
	^ coursewareList! !

!CoursewareManager methodsFor: 'updating' stamp: 'has 6/24/2013 07:30'!
unblockCourseware: aCourseware user: anUser
	"I unblock the couseware if the user has the permissions to do this"

	| notification |
	anUser isUser.
	aCourseware isCourseware.
	notification := OCMSNotificationManager new.
	
	(anUser isAdmin or: (self isOwner: anUser ofCourseware: aCourseware) or: (self isProfessor: anUser atCourseware: aCourseware))
		ifTrue:[(aCourseware isEnabled not)
				ifTrue:[aCourseware isEnabled: true]
				ifFalse:[self error: 'This courseware was already enabled.'].
				]
		ifFalse:[self error: 'You do not have permission to unblock this courseware.'].
	self updateCourseware: aCourseware.
	notification unblockCoursewareNotification: aCourseware.
	^ aCourseware! !

!CoursewareManager methodsFor: 'updating' stamp: 'has 6/24/2013 07:07'!
updateCourseware: aCourseware
	"i update the courseware information"
	
	aCourseware isCourseware.
	Coursewares update: aCourseware.! !

!CoursewareManager methodsFor: 'updating' stamp: 'has 6/24/2013 07:09'!
updateCourseware: aCourseware withTitle: aTitle withDescription: aDescription withSummary: aSummary withCoursewareType: aCoursewareType withReference: aReference withTag: aTagList withCourse: aCourseList withAuthor: aAuthorList withCataloguingData: aCataloguingData withLicense: aLicenseType withSize: aSize withScore: aUserFloatDictionary withPermission: aUserPermissionTypeDictionary withFile: aFile
	"i update the courseware information"
	
	| coursewareTemp |
	coursewareTemp := aCourseware.
	coursewareTemp title: aTitle.
	coursewareTemp description: aDescription.
	coursewareTemp summary: aSummary.
	coursewareTemp coursewareType: aCoursewareType.
	coursewareTemp reference: aReference.
	coursewareTemp tag: aTagList.
	coursewareTemp course: aCourseList.
	coursewareTemp author: aAuthorList.
	coursewareTemp modificationDateTime: DateAndTime now.
	coursewareTemp cataloguingData: aCataloguingData.
	coursewareTemp license: aLicenseType.
	coursewareTemp size: aSize.
	coursewareTemp score: aUserFloatDictionary.
	coursewareTemp permission: aUserPermissionTypeDictionary.
	coursewareTemp file: aFile.
	self updateCourseware: coursewareTemp.
	^coursewareTemp.
	! !

Object subclass: #CoursewareType
	instanceVariableNames: ''
	classVariableNames: 'CoursewareTypeList'
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!CoursewareType commentStamp: '<historical>' prior: 0!
UserType class is used to enumerate roles of users, so it can be used to set roles of users within Disciplines.

There are the following roles that can be accessed by class methods:
	student
	professor

UserTypeList is a class variable that contains a set with all roles availables.
!

!CoursewareType class methodsFor: 'accessing' stamp: 'has 6/24/2013 09:49'!
audio
	^ #Audio! !

!CoursewareType class methodsFor: 'accessing' stamp: 'has 6/24/2013 09:49'!
code
	^ #Code! !

!CoursewareType class methodsFor: 'class variables' stamp: 'has 6/24/2013 09:55'!
coursewareTypeList
	CoursewareTypeList ifNil: [CoursewareTypeList := Set new add: CoursewareType audio; 
																add: CoursewareType code;
																add: CoursewareType exercise; 
																add: CoursewareType program; 
																add: CoursewareType slide; 
																add: CoursewareType text; 
																add: CoursewareType video; 
																yourself].
	^ CoursewareTypeList! !

!CoursewareType class methodsFor: 'accessing' stamp: 'has 6/24/2013 09:49'!
exercise
	^ #Exercise! !

!CoursewareType class methodsFor: 'instance creation' stamp: 'has 6/24/2013 09:43'!
new
	self error: 'This class should not be instanciated'! !

!CoursewareType class methodsFor: 'accessing' stamp: 'has 6/24/2013 09:50'!
program
	^ #Program! !

!CoursewareType class methodsFor: 'accessing' stamp: 'has 6/24/2013 09:50'!
slide
	^ #Slide! !

!CoursewareType class methodsFor: 'accessing' stamp: 'has 6/24/2013 09:50'!
text
	^ #Text! !

!CoursewareType class methodsFor: 'accessing' stamp: 'has 6/24/2013 09:50'!
video
	^ #Video! !

Object subclass: #Group
	instanceVariableNames: 'description owner creationDateTime isEnabled isOpen password course userRole'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!Group methodsFor: 'comparing' stamp: 'oda 7/1/2013 18:52'!
<= aGroup
	^self description <= aGroup description.
	! !

!Group methodsFor: 'comparing' stamp: 'has 6/27/2013 09:55'!
= aGroup
	^self description = aGroup description.! !

!Group methodsFor: 'testing' stamp: 'oda 7/1/2013 03:01'!
containsUser: anUser
	^userRole keys contains: anUser.! !

!Group methodsFor: 'accessing' stamp: 'oda 6/24/2013 23:09'!
course
	^ course! !

!Group methodsFor: 'accessing' stamp: 'oda 6/24/2013 23:09'!
course: aCourse
	course := aCourse! !

!Group methodsFor: 'accessing' stamp: 'oda 6/24/2013 22:32'!
creationDateTime
	^ creationDateTime! !

!Group methodsFor: 'accessing' stamp: 'oda 6/24/2013 22:33'!
creationDateTime: aDateTime
	creationDateTime := aDateTime! !

!Group methodsFor: 'accessing' stamp: 'has 6/27/2013 09:56'!
description
	^description! !

!Group methodsFor: 'accessing' stamp: 'has 6/27/2013 09:56'!
description: aString
	description := aString! !

!Group methodsFor: 'accessing' stamp: 'has 6/28/2013 17:48'!
getAllGroupModerators
	"i return all moderators of the group related to the course"
	| listModerator |
	listModerator := OrderedCollection new.
	userRole keysDo:[:each | ((self roleOfUser: each) = UserType moderator)
									ifTrue:[ listModerator add: each].].
	^listModerator.! !

!Group methodsFor: 'comparing' stamp: 'has 6/27/2013 09:55'!
hash
	^ description hash! !

!Group methodsFor: 'updating' stamp: 'oda 6/26/2013 21:12'!
includeOrUpdateUser: anUser withRole:  aRole
	"Inserts user with a specific role within the group, should be called by User->includeOrUpdateGroup: withRol:"
	anUser isUser.
	UserType validateRole: aRole.
	
	userRole at: anUser put: aRole! !

!Group methodsFor: 'initialize-release' stamp: 'oda 7/1/2013 03:00'!
initialize
	userRole := Dictionary new.
	isEnabled := false.
	isOpen := true.! !

!Group methodsFor: 'accessing' stamp: 'oda 6/24/2013 22:33'!
isEnabled
	^ isEnabled! !

!Group methodsFor: 'accessing' stamp: 'oda 6/24/2013 22:33'!
isEnabled: aBoolean
	isEnabled := aBoolean! !

!Group methodsFor: 'testing' stamp: 'oda 6/24/2013 23:33'!
isGroup
	^true! !

!Group methodsFor: 'accessing' stamp: 'oda 6/24/2013 22:33'!
isOpen
	^ isOpen! !

!Group methodsFor: 'accessing' stamp: 'oda 6/24/2013 22:33'!
isOpen: aBoolean
	isOpen := aBoolean! !

!Group methodsFor: 'accessing' stamp: 'oda 6/24/2013 22:32'!
owner
	^ owner! !

!Group methodsFor: 'accessing' stamp: 'oda 6/24/2013 22:32'!
owner: anUser
	owner := anUser! !

!Group methodsFor: 'accessing' stamp: 'oda 6/24/2013 22:34'!
password
	^ password! !

!Group methodsFor: 'accessing' stamp: 'oda 6/24/2013 22:34'!
password: aString
	password := aString! !

!Group methodsFor: 'updating' stamp: 'oda 6/26/2013 21:13'!
removeUser: anUser
	"Removes user of the group, should be called by User->removeGroup:"
	userRole remove: anUser! !

!Group methodsFor: 'accessing' stamp: 'oda 6/26/2013 21:02'!
roleOfUser: anUser
	^ userRole at: anUser.! !

!Group methodsFor: 'accessing' stamp: 'oda 6/26/2013 21:01'!
user
	^ userRole keys.! !

Object subclass: #GroupManager
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!GroupManager commentStamp: '<historical>' prior: 0!
Store the tags used to classify courseware.

	name <String>							Name of the tag.
	relatedTag <OrderedCollection of: Tag>		Contains the related tags.!

!GroupManager methodsFor: 'updating' stamp: 'oda 7/1/2013 18:37'!
blockGroup: aGroup
	"Blocks group.."
	
	"userSession"
	| notification |
	aGroup isGroup.
	notification := OCMSNotificationManager new.
	aGroup isEnabled: false.
	Groups update: aGroup.
	notification blockGroupNotification: aGroup.
! !

!GroupManager methodsFor: 'testing' stamp: 'oda 7/1/2013 19:05'!
groupExists: aGroup at: aCourse
	"I check if group already exists"
	| groupTemp |
	groupTemp:=Groups searchByDescription: aGroup description andCourse: aCourse.
	^groupTemp notNil
! !

!GroupManager methodsFor: 'creating' stamp: 'oda 7/1/2013 19:06'!
includeGroup: aGroup atCourse: aCourse byUser: anUser
	"i include a group in database"

	| notification |
	notification := OCMSNotificationManager new.
	self validateGroup: aGroup at: aCourse.
	Groups add: aGroup at: aCourse by: anUser.
	notification newGroupNotification: aGroup! !

!GroupManager methodsFor: 'updating' stamp: 'has 7/2/2013 09:47'!
removeGroup: aGroup
	"i remove a Group"
	| notification |
	aGroup isGroup.
	notification := OCMSNotificationManager new.
	notification removeGroupNotification: aGroup.
	Groups remove: aGroup.! !

!GroupManager methodsFor: 'accessing' stamp: 'oda 6/30/2013 22:00'!
searchGroup: aGroup
	"i return a collection of groups that contains the typed word"
	| groupList |
	
	groupList := OrderedCollection new.
	groupList := Groups searchByDescription: aGroup description andCourse: aGroup course.
	^ groupList.! !

!GroupManager methodsFor: 'updating' stamp: 'oda 7/1/2013 18:37'!
unblockGroup: aGroup
	"Unblocks group.."
	
	"userSession"
	| notification |
	aGroup isGroup.
	notification := OCMSNotificationManager new.
	aGroup isEnabled: true.
	Groups update: aGroup.
	notification unblockGroupNotification: aGroup.
! !

!GroupManager methodsFor: 'updating' stamp: 'oda 7/1/2013 02:47'!
updateGroup: aGroup
	"i update a Group"

	self validateGroupToBeUpdated: aGroup.  
	Groups update: aGroup.! !

!GroupManager methodsFor: 'creating' stamp: 'oda 7/1/2013 19:05'!
validateGroup: aGroup at: aCourse
	self validateGroupToBeUpdated: aGroup.  
	
	(self groupExists: aGroup at: aCourse)
		ifTrue: [ self error: 'This group is already used' ].

! !

!GroupManager methodsFor: 'creating' stamp: 'oda 7/1/2013 02:46'!
validateGroupToBeUpdated: aGroup
	aGroup isGroup.
	OCMSUtilities ifNotAlphanum: aGroup description raiseError: 'Invalid name'.
	

! !

Object subclass: #LicenseType
	instanceVariableNames: ''
	classVariableNames: 'LicenseTypeList'
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!LicenseType commentStamp: '<historical>' prior: 0!
UserType class is used to enumerate roles of users, so it can be used to set roles of users within Disciplines.

There are the following roles that can be accessed by class methods:
	student
	professor

UserTypeList is a class variable that contains a set with all roles availables.
!

!LicenseType class methodsFor: 'accessing' stamp: 'has 6/29/2013 18:51'!
creativeCommons
	^ #CreativeCommons! !

!LicenseType class methodsFor: 'class variables' stamp: 'has 6/30/2013 15:57'!
licenseTypeList
	LicenseTypeList ifNil: [LicenseTypeList := Set new add: LicenseType publicDomain; 
														add: LicenseType creativeCommons;
														yourself].
	^ LicenseTypeList! !

!LicenseType class methodsFor: 'instance creation' stamp: 'has 6/29/2013 18:48'!
new
	self error: 'This class should not be instanciated'! !

!LicenseType class methodsFor: 'accessing' stamp: 'has 6/29/2013 18:51'!
publicDomain
	^ #PublicDomain! !

!LicenseType class methodsFor: 'class variables' stamp: 'has 6/30/2013 15:58'!
resetLicenseTypes
	"i reset the roles in UserTypeList"
	LicenseTypeList := nil.! !

Object subclass: #OCMSNotification
	instanceVariableNames: 'id title body sender receiverIsRead isSystemNotification dateAndTime'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!OCMSNotification methodsFor: 'comparing' stamp: 'oda 7/1/2013 20:44'!
<= aOCMSNotification
	^self dateAndTime <= aOCMSNotification dateAndTime.! !

!OCMSNotification methodsFor: 'comparing' stamp: 'oda 5/12/2013 22:58'!
= aOCMSNotification
	^self hash = aOCMSNotification hash.! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/13/2013 03:52'!
addReceiver: anUser
	"Adds a receiver with the relation that the message has not been read."
	receiverIsRead at: anUser put: false.! !

!OCMSNotification methodsFor: 'accessing' stamp: 'has 6/23/2013 11:51'!
addReceiverList: anUserList
	"I add a list of receivers with the relation that the message has not been read."
	anUserList do: [:each | receiverIsRead at: each put: false.].! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/12/2013 23:32'!
body
	"Answer the value of body"

	^ body! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/12/2013 23:32'!
body: anObject
	"Set the value of body"

	body := anObject! !

!OCMSNotification methodsFor: 'accessing' stamp: 'has 6/23/2013 07:59'!
createId
	id:= self hash.! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/12/2013 22:13'!
dateAndTime
	"Answer the value of dateAndTime"

	^ dateAndTime! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/12/2013 22:13'!
dateAndTime: anObject
	"Set the value of dateAndTime"

	dateAndTime := anObject! !

!OCMSNotification methodsFor: 'comparing' stamp: 'has 6/24/2013 15:46'!
hash
	| receiverLogin senderLogin|
	receiverLogin := ''.
	self receiver do: [:each | receiverLogin := receiverLogin, '|', each ].
	(sender isNil)
		ifTrue: [senderLogin := '']
		ifFalse: [senderLogin := sender login].
	
	^ [title, '|',  body, receiverLogin, '|', senderLogin, '|', dateAndTime] value hash.! !

!OCMSNotification methodsFor: 'accessing' stamp: 'has 6/23/2013 07:57'!
id
	^id.! !

!OCMSNotification methodsFor: 'initialize-release' stamp: 'oda 5/13/2013 04:30'!
initialize
	sender := nil.
	receiverIsRead := Dictionary new.
	isSystemNotification := false.
	dateAndTime := DateAndTime now.! !

!OCMSNotification methodsFor: 'testing' stamp: 'has 6/23/2013 15:14'!
isOCMSNotification
	^true.! !

!OCMSNotification methodsFor: 'accessing' stamp: 'has 6/24/2013 17:25'!
isReadByUser: anUser
	^ receiverIsRead at: anUser.
	! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/12/2013 22:24'!
isSystemNotification
	"Answer the value of isSystemNotification"

	^ isSystemNotification! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/12/2013 22:24'!
isSystemNotification: anObject
	"Set the value of isSystemNotification"

	isSystemNotification := anObject! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 7/1/2013 20:36'!
readWithUser: anUser
	(self receiver includes: anUser)
		ifTrue: [
			receiverIsRead at: anUser put: true.
			OCMSNotifications update: self.
		]
		ifFalse:[self error: 'This user is not a receiver of this notification.'].! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/13/2013 03:53'!
receiver
	"Answer the value of receiver set"

	^ receiverIsRead keys.! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/13/2013 04:03'!
receiverIsRead
	"Answer the value of receiverIsRead"

	^ receiverIsRead.! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/12/2013 22:13'!
sender
	"Answer the value of sender"

	^ sender! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/12/2013 22:13'!
sender: anObject
	"Set the value of sender"

	sender := anObject! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/12/2013 22:13'!
title
	"Answer the value of title"

	^ title! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/12/2013 22:13'!
title: anObject
	"Set the value of title"

	title := anObject! !

Object subclass: #OCMSNotificationManager
	instanceVariableNames: 'notification'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/28/2013 18:13'!
blockCoursewareNotification: aCourseware
	"I create a notification when a courseware is blocked."
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: 'Courseware blocked'.
	newNotification body: 'The courseware ',aCourseware title,' was blocked.'.
	newNotification isSystemNotification: true.
	receivers add: aCourseware owner.
	receivers addAll: userManager getAllAdmins.
	receivers addAll: aCourseware usersWithWritePermission.
	((aCourseware course) size > 0)
		ifTrue:[(aCourseware course) do: [:each | receivers addAll: (each getAllCourseModerators)]].
	"tirar duplicados"
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'oda 7/1/2013 18:36'!
blockGroupNotification: aGroup
	"I create a notification when a user is blocked"
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: 'Group blocked'.
	newNotification body: 'The group with name ', aGroup description ,' was blocked.'.
	newNotification isSystemNotification: true.
	receivers addAll: aGroup user.
	receivers addAll: userManager getAllAdmins.
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/23/2013 18:59'!
blockUserNotification: anUser
	"I create a notification when a user is blocked"
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: 'User blocked'.
	newNotification body: 'The user with login ',anUser login,' was blocked.'.
	newNotification isSystemNotification: true.
	receivers add: anUser.
	receivers addAll: userManager getAllAdmins.
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'accessing' stamp: 'has 6/24/2013 17:40'!
hasUnreadNotificationOfUser: anUser
	"Returns true if exists at least one unread notification received by anUser"
	| aSet notificationTemp |
	notificationTemp := self receivedNotificationOfUser:anUser.
	aSet := (notificationTemp select: [:each | ((each isReadByUser: anUser) = false)]).
	^aSet isEmpty not.
	! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/23/2013 15:19'!
includeNotification: newNotification
	"I include a new notification in database."
	newNotification isOCMSNotification.
	newNotification createId.
	OCMSNotifications add: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/28/2013 18:13'!
includeWritePermissionNotification: anUser ofCourseware: aCourseware
	"I create a notification when an user has write permissions to a courseware."
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: 'Write permissions to courseware'.
	newNotification body: anUser login,' now has write permission to courseware ',aCourseware title,'.'.
	newNotification isSystemNotification: true.
	receivers add: aCourseware owner.
	receivers add: anUser.
	((aCourseware course) size > 0)
		ifTrue:[(aCourseware course) do: [:each | receivers addAll: (each getAllCourseModerators)]].
	"tirar duplicados"
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'initialize-release' stamp: 'oda 5/12/2013 23:04'!
initialize
	notification := Set new.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/23/2013 16:51'!
newCommentNotification: aComment ofCourseware: aCourseware
	"I create a notification when a comment is created"
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: 'New comment'.
	newNotification body: 'User ',(aComment user) login,' made a comment about ', aCourseware.
	newNotification isSystemNotification: true.
	receivers add: aCourseware owner.
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/27/2013 10:17'!
newCourseNotification: aCourse
	"I create a notification when a new course is created"
	
	| newNotification receivers courseManager userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	courseManager:= CourseManager new.
	userManager:= UserManager new.
	newNotification title: 'New course'.
	newNotification body: 'A new course named ',aCourse description,' was created.'.
	newNotification isSystemNotification: true.
	receivers addAll: aCourse group.
	receivers addAll: userManager getAllAdmins.
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/28/2013 17:51'!
newCoursewareNotification: aCourseware
	"I create a notification when a new courseware is created."
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: 'New courseware'.
	newNotification body: 'A new courseware with the title ',aCourseware title,' was created.'.
	newNotification isSystemNotification: true.
	receivers add: aCourseware owner.
	((aCourseware course) size > 0)
		ifTrue:[(aCourseware course) do: [:each | receivers addAll: (each getAllCourseModerators)]].
	"tirar duplicados"
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/27/2013 10:24'!
newGroupNotification: aGroup
	"I create a notification when a new group is created"
	
	| newNotification receivers groupManager userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	groupManager:= CourseManager new.
	userManager:= UserManager new.
	newNotification title: 'New group'.
	newNotification body: 'A new group  ',aGroup description,' was created.'.
	newNotification isSystemNotification: true.
	receivers add: aGroup owner.
	receivers addAll: userManager getAllAdmins.
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/23/2013 15:22'!
newUserNotification: anUser
	"I create a notification when a new user is created"
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: 'New user'.
	newNotification body: 'A new user with login ',anUser login,' was created.'.
	newNotification isSystemNotification: true.
	receivers add: anUser.
	receivers addAll: userManager getAllAdmins.
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'accessing' stamp: 'oda 5/13/2013 03:19'!
notification
	"Answer the value of notification"

	^ notification! !

!OCMSNotificationManager methodsFor: 'accessing' stamp: 'has 6/24/2013 17:42'!
receivedNotificationOfUser: anUser
	"I return all notifications received by anUser"
	| notificationTemp userNotification |
	anUser isUser.
	notificationTemp := OCMSNotifications getAll.
	userNotification := (notificationTemp select: [:each | ((each receiver includes: anUser) = true)]).
	^userNotification.
	! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 7/2/2013 09:44'!
removeCourseNotification: aCourse
	"I create a notification when a course is removed.
	Use me before remove the course."
	
	| newNotification receivers courseManager userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	courseManager:= CourseManager new.
	userManager:= UserManager new.
	newNotification title: 'Course deleted'.
	newNotification body: 'The course named ',aCourse description,' was deleted.'.
	newNotification isSystemNotification: true.
	receivers addAll: aCourse group.
	receivers addAll: userManager getAllAdmins.
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 7/2/2013 09:43'!
removeCoursewareNotification: aCourseware
	"I create a notification when a courseware is removed.
	Use me before remove the courseware."
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: 'Courseware deleted'.
	newNotification body: 'The courseware with the title ',aCourseware title,' was deleted.'.
	newNotification isSystemNotification: true.
	receivers add: aCourseware owner.
	((aCourseware course) size > 0)
		ifTrue:[(aCourseware course) do: [:each | receivers addAll: (each getAllCourseModerators)]].
	"tirar duplicados"
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 7/2/2013 09:44'!
removeGroupNotification: aGroup
	"I create a notification when a group is removed.
	Use me before remove the group."
	
	| newNotification receivers groupManager userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	groupManager:= CourseManager new.
	userManager:= UserManager new.
	newNotification title: 'Group deleted'.
	newNotification body: 'The group  ',aGroup description,' was deleted.'.
	newNotification isSystemNotification: true.
	receivers add: aGroup owner.
	receivers addAll: userManager getAllAdmins.
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'updating' stamp: 'has 6/24/2013 17:44'!
removeNotification: aNotification
	"i remove the notification"
	aNotification isOCMSNotification.
	OCMSNotifications remove: aNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 7/2/2013 09:41'!
removeUserNotification: anUser
	"I create a notification when a user is removed"
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: 'User deleted'.
	newNotification body: 'The user with login ',anUser login,' was deleted.'.
	newNotification isSystemNotification: true.
	receivers addAll: userManager getAllAdmins.
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/28/2013 18:09'!
removeWritePermissionNotification: anUser ofCourseware: aCourseware
	"I create a notification when an user lost his write permissions to a courseware."
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: 'Lost write permissions to courseware'.
	newNotification body: anUser login,' lost his write permissions to courseware ',aCourseware title,'.'.
	newNotification isSystemNotification: true.
	receivers add: aCourseware owner.
	receivers add: anUser.
	((aCourseware course) size > 0)
		ifTrue:[(aCourseware course) do: [:each | receivers addAll: (each getAllCourseModerators)]].
	"tirar duplicados"
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/23/2013 19:13'!
scoreNotification: anUser ofCourseware: aCourseware
	"I create a notification when a score is assigned to a courseware"
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: 'New score'.
	newNotification body: 'User ',anUser login,' assigned a score for', aCourseware.
	newNotification isSystemNotification: true.
	receivers add: aCourseware owner.
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/23/2013 19:26'!
sendMessageToAdminFrom: anUser withTitle: aTitle withContent: aMessage
	"I create a message to be sent to admin group"
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: aTitle.
	newNotification body: aMessage.
	newNotification isSystemNotification: false.
	newNotification sender: anUser.
	receivers addAll: userManager getAllAdmins.
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/28/2013 18:11'!
sendMessageToModeratorsFrom: anUser ofCourse: aCourse withTitle: aTitle withContent: aMessage
	"I create a message to be sent to moderators of a course"
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: aTitle.
	newNotification body: aMessage.
	newNotification isSystemNotification: false.
	newNotification sender: anUser.
	receivers addAll: (aCourse getAllCourseModerators).
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/23/2013 19:33'!
sendMessageToOwnerFrom: anUser ofCourseware: aCourseware withTitle: aTitle withContent: aMessage
	"I create a message to be sent to the owner of a courseware"
	
	| newNotification receivers |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	newNotification title: aTitle.
	newNotification body: aMessage.
	newNotification isSystemNotification: false.
	newNotification sender: anUser.
	receivers add: aCourseware owner.
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/28/2013 18:12'!
sendMessageToWritePermissionsUsersFrom: anUser ofCourseware: aCourseware withTitle: aTitle withContent: aMessage
	"I create a message to be sent to users with write permissions of a courseware"
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: aTitle.
	newNotification body: aMessage.
	newNotification isSystemNotification: false.
	newNotification sender: anUser.
	receivers add: aCourseware owner.
	receivers addAll: aCourseware usersWithWritePermission.
	((aCourseware course) size > 0)
		ifTrue:[(aCourseware course) do: [:each | receivers addAll: (each getAllCourseModerators)]].
	"tirar duplicados"
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'accessing' stamp: 'has 6/24/2013 17:48'!
sentNotificationOfUser: anUser
	"I return all notifications that were sent by anUser"
	| notificationTemp userNotification |
	anUser isUser.
	notificationTemp := OCMSNotifications getAll.
	userNotification := notificationTemp select: [:each | (each sender = anUser)].
	^userNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/28/2013 18:12'!
unblockCoursewareNotification: aCourseware
	"I create a notification when a courseware is unblocked."
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: 'Courseware unblocked'.
	newNotification body: 'The courseware ',aCourseware title,' was unblocked.'.
	newNotification isSystemNotification: true.
	receivers add: aCourseware owner.
	receivers addAll: userManager getAllAdmins.
	receivers addAll: aCourseware usersWithWritePermission.
	((aCourseware course) size > 0)
		ifTrue:[(aCourseware course) do: [:each | receivers addAll: (each getAllCourseModerators)]].
	"tirar duplicados"
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'oda 7/1/2013 18:37'!
unblockGroupNotification: aGroup
	"I create a notification when a user is blocked"
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: 'Group unblocked'.
	newNotification body: 'The group with name ', aGroup description ,' was unblocked.'.
	newNotification isSystemNotification: true.
	receivers addAll: aGroup user.
	receivers addAll: userManager getAllAdmins.
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/23/2013 18:59'!
unblockUserNotification: anUser
	"I create a notification when a user is unblocked"
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: 'User unblocked'.
	newNotification body: 'The user with login ',anUser login,' was unblocked.'.
	newNotification isSystemNotification: true.
	receivers add: anUser.
	receivers addAll: userManager getAllAdmins.
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

Object subclass: #OCMSUtilities
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!OCMSUtilities class methodsFor: 'testing' stamp: 'oda 6/30/2013 23:16'!
ifNotAlphanum: aString raiseError: anErrorString
	(aString isNil or:
		[(aString isEmpty) or:
		[(OCMSUtilities validString: aString) not]]) ifTrue: [
			self error: anErrorString.  
		].


! !

!OCMSUtilities class methodsFor: 'testing' stamp: 'oda 6/30/2013 23:05'!
validString: aString
	aString do: [:each |
		(each isAlphaNumeric) ifFalse: [^false]
	].
	^true.

! !

Object subclass: #Tag
	instanceVariableNames: 'label'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!Tag commentStamp: 'HAS 4/28/2013 16:34' prior: 0!
Store the tags used to classify courseware.

	name <String>							Name of the tag.
	relatedTag <OrderedCollection of: Tag>		Contains the related tags.!

!Tag methodsFor: 'testing' stamp: 'HAS 4/28/2013 19:52'!
isTag
	^ true! !

!Tag methodsFor: 'accessing' stamp: 'has 6/26/2013 23:52'!
label
	^label.! !

!Tag methodsFor: 'accessing' stamp: 'has 6/26/2013 23:52'!
label: aLabel
	label := aLabel.! !

Object subclass: #TagManager
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!TagManager commentStamp: '<historical>' prior: 0!
Store the tags used to classify courseware.

	name <String>							Name of the tag.
	relatedTag <OrderedCollection of: Tag>		Contains the related tags.!

!TagManager methodsFor: 'creating' stamp: 'has 6/28/2013 15:07'!
includeTag: aTagName
	"i include a Tag"
	| tag |
	(Tags labelExists: aTagName)
		ifFalse:[ tag := Tag new.
				tag label: aTagName.
				Tags add: tag. ]
		ifTrue:[self error: 'This tag already exists.'].
	! !

!TagManager methodsFor: 'updating' stamp: 'has 6/28/2013 15:09'!
removeTag: aTag
	"i remove a Tag"
	Tags remove: aTag.! !

!TagManager methodsFor: 'accessing' stamp: 'has 7/1/2013 10:56'!
searchAllTags
	"i return a collection of all tags"
	
	| tagList tagOrdered |
	tagList := OrderedCollection new.
	tagList := Tags getAll.
	tagOrdered:= OrderedCollection new.
	tagList do:[:each | tagOrdered add: each ].
	^ tagOrdered.! !

!TagManager methodsFor: 'accessing' stamp: 'has 6/28/2013 15:13'!
searchTag: aTagName
	"i return a collection of tags that contains the typed word"
	| tagList |
	
	tagList := OrderedCollection new.
	tagList := Tags searchTagByLabel: aTagName. "as OrderedCollection."
	^ tagList.! !

!TagManager methodsFor: 'testing' stamp: 'has 6/30/2013 10:29'!
tagExists: aTagName
	| tagList |
	tagList:= self searchTag: aTagName.
	tagList do:[:each | (each label = aTagName)
						ifTrue:[^true]].
	^false.! !

!TagManager methodsFor: 'updating' stamp: 'has 6/24/2013 13:29'!
updateTag: aTag
	"i update a Tag"
	
	Tags update: aTag.! !

Object subclass: #User
	instanceVariableNames: 'username email login password isAdmin isEnabled group'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!User commentStamp: 'oda 5/1/2013 20:21' prior: 0!
Contains information about user.

Instance Variables
	disciplineRole <Dictionary<Discipline, UserType>>		stores the role of the user within a discipline
	email <String>
	isEnabled <Boolean>
	isAdmin <Boolean>
	login <String>
	name <String>
	password <String>
!

!User methodsFor: 'comparing' stamp: 'oda 5/12/2013 21:55'!
= aUser
	^self login = aUser login! !

!User methodsFor: 'accessing' stamp: 'oda 6/24/2013 23:14'!
course
	"Answer the courses that the user is member of"
	
	^ (self group collect: [:each | each course]) asSet.! !

!User methodsFor: 'accessing' stamp: 'oda 5/1/2013 20:41'!
email
	^ email! !

!User methodsFor: 'accessing' stamp: 'oda 5/1/2013 20:41'!
email: aString
	email := aString! !

!User methodsFor: 'accessing' stamp: 'oda 6/24/2013 23:15'!
group
	"Answer the groups that the member is member of"
	^ group! !

!User methodsFor: 'accessing' stamp: 'oda 6/24/2013 23:12'!
group: aCollection
	group := aCollection! !

!User methodsFor: 'comparing' stamp: 'oda 5/1/2013 22:59'!
hash
	^ login hash! !

!User methodsFor: 'creating' stamp: 'oda 6/26/2013 21:08'!
includeOrUpdateGroup: aGroup withRole: aRole
	"Insert or updates the role of the user within a group."
	aGroup isGroup.
	group add: aGroup.
	aGroup includeOrUpdateUser: self withRole: aRole! !

!User methodsFor: 'initialize-release' stamp: 'oda 7/1/2013 18:48'!
initialize
	isEnabled := false.
	isAdmin := false.
	group := OrderedCollection new.
	
	! !

!User methodsFor: 'accessing' stamp: 'oda 5/1/2013 20:41'!
isAdmin
	^ isAdmin! !

!User methodsFor: 'accessing' stamp: 'oda 5/1/2013 21:03'!
isAdmin: aBoolean
	isAdmin := aBoolean! !

!User methodsFor: 'accessing' stamp: 'oda 5/1/2013 20:41'!
isEnabled
	^ isEnabled! !

!User methodsFor: 'accessing' stamp: 'oda 5/1/2013 20:58'!
isEnabled: aBoolean
	isEnabled := aBoolean! !

!User methodsFor: 'testing' stamp: 'has 6/1/2013 18:14'!
isUser
	^ true! !

!User methodsFor: 'creating' stamp: 'oda 7/1/2013 03:18'!
joinGroup: aGroup
	"Insert user within a group as student"
	self includeOrUpdateGroup: aGroup withRole: UserType student.
	^true.
	! !

!User methodsFor: 'creating' stamp: 'oda 7/1/2013 04:16'!
joinGroup: aGroup withPassword: aPassword
	"Check group password.
	Insert user within a group as student."
	(aGroup password = aPassword hash)
		ifTrue: [
			self includeOrUpdateGroup: aGroup withRole: UserType student.
			^true.
		].
	^false.! !

!User methodsFor: 'accessing' stamp: 'oda 5/1/2013 20:58'!
login
	^ login! !

!User methodsFor: 'accessing' stamp: 'oda 5/1/2013 20:58'!
login: aString
	login := aString! !

!User methodsFor: 'accessing' stamp: 'oda 5/1/2013 20:42'!
password
	^ password! !

!User methodsFor: 'accessing' stamp: 'oda 6/29/2013 20:02'!
password: aString
	password := aString hash.! !

!User methodsFor: 'updating' stamp: 'oda 7/1/2013 17:56'!
removeGroup: aGroup
	"Removes this user of aGroup."
	group remove: aGroup.! !

!User methodsFor: 'accessing' stamp: 'oda 6/26/2013 21:04'!
roleAtGroup: aGroup
	"Answer the role of user within a group"
	
	aGroup isGroup.
	^ aGroup roleOfUser: self.  ! !

!User methodsFor: 'accessing' stamp: 'has 6/27/2013 19:07'!
username
	^ username! !

!User methodsFor: 'accessing' stamp: 'has 6/27/2013 19:08'!
username: aString
	username := aString! !

!User methodsFor: 'accessing' stamp: 'oda 6/29/2013 20:04'!
verifyPassword: aString
	^ aString hash = password.! !

Object subclass: #UserManager
	instanceVariableNames: 'user'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!UserManager commentStamp: 'oda 5/3/2013 22:00' prior: 0!
Manages users, can include new users, update existing ones, block/unblock users and is responsible for authentication.

Instance Variables
	user:<Set<User>>!

!UserManager methodsFor: 'testing' stamp: 'oda 7/1/2013 17:51'!
authenticateUserWithLogin: aLogin withPassword: aPassword
	"Asserts if user with aLogin exists and the password is correct."
	| anUser |
	anUser := self userWithLogin: aLogin.
	(anUser notNil
		and: [anUser isEnabled
		and: [anUser verifyPassword: aPassword]])
			ifTrue: [^anUser]
			ifFalse: [^nil].  
! !

!UserManager methodsFor: 'updating' stamp: 'has 6/24/2013 20:58'!
blockUser: anUser
	"Blocks user."
	
	"userSession"
	| notification |
	anUser isUser.
	notification := OCMSNotificationManager new.
	"(userSession isAdmin)"
	(true)
		ifTrue:[	(anUser isEnabled)
					ifTrue:[	anUser isEnabled: false.
							Users update: anUser.
							notification blockUserNotification: anUser.]
					ifFalse:[self error: 'The user is already blocked.']]
		ifFalse:[self error: 'You do not have permissions to block an user'].! !

!UserManager methodsFor: 'updating' stamp: 'has 6/2/2013 22:51'!
blockUserWithLogin: aLogin
	"Blocks user"
	| anUser |
	anUser := self userWithLogin: aLogin.
	self blockUser: anUser.! !

!UserManager methodsFor: 'testing' stamp: 'has 6/23/2013 11:03'!
emailExists: anEmail
	"I check if email already exists"
	| userTemp |
	userTemp:=Users searchByEmail: anEmail.
	(userTemp isNil)
		ifTrue:[^false]
		ifFalse:[^true].
	! !

!UserManager methodsFor: 'accessing' stamp: 'has 6/23/2013 12:31'!
getAllAdmins
	| admins users |
	users:= Users getAll.
	admins:= OrderedCollection new.
	users do:[:each | (each isAdmin)
						ifTrue:[admins add: each].].
	^admins.
	! !

!UserManager methodsFor: 'creating' stamp: 'oda 6/29/2013 18:57'!
includeUser: anUser
	"I include a new user in database."
	| notification |
	self validateUser: anUser.

	notification:= OCMSNotificationManager new.
	Users add: anUser.
	notification newUserNotification: anUser.! !

!UserManager methodsFor: 'creating' stamp: 'has 6/27/2013 19:19'!
includeUserWithLogin: aLogin withPassword: aPassword withEmail: anEmail withName: aName isAdmin: anAdminFlag
	"Includes a new user."
	| newUser |
	newUser := User new login: aLogin;
						password: aPassword;
						email: anEmail;
						username: aName;
						isAdmin: anAdminFlag.
	^self includeUser: newUser.! !

!UserManager methodsFor: 'initialize-release' stamp: 'oda 5/1/2013 20:39'!
initialize
	user := Set new.! !

!UserManager methodsFor: 'testing' stamp: 'has 6/23/2013 10:56'!
loginExists: aLogin
	"I check if login already exists"
	| userTemp |
	userTemp:=Users searchByLogin: aLogin.
	(userTemp isNil)
		ifTrue:[^false]
		ifFalse:[^true].
	! !

!UserManager methodsFor: 'updating' stamp: 'has 7/2/2013 09:48'!
removeUser: anUser
	"I remove user"
	| notification |
	anUser isUser.
	notification := OCMSNotificationManager new.
	notification removeUserNotification: anUser.
	Users remove: anUser.! !

!UserManager methodsFor: 'updating' stamp: 'has 6/2/2013 22:56'!
removeUserWithLogin: aLogin
	"Removes user"
	| anUser |
	anUser := self userWithLogin: aLogin.
	self removeUser: anUser.! !

!UserManager methodsFor: 'updating' stamp: 'has 6/25/2013 06:49'!
unblockUser: anUser
	"Unblocks user."
	
	"userSession"
	| notification |
	anUser isUser.
	notification := OCMSNotificationManager new.
	"(userSession isAdmin)"(true)
		ifTrue:[	(anUser isEnabled)
					ifFalse:[	anUser isEnabled: true.
							Users update: anUser.
							notification unblockUserNotification: anUser.]
					ifTrue:[self error: 'The user is already unblocked.']]
		ifFalse:[self error: 'You do not have permissions to block an user'].! !

!UserManager methodsFor: 'updating' stamp: 'has 6/25/2013 06:51'!
unblockUserWithLogin: aLogin
	"Unblocks user"
	| anUser |
	anUser := self userWithLogin: aLogin.
	self unblockUser: anUser.! !

!UserManager methodsFor: 'updating' stamp: 'has 6/24/2013 14:15'!
updateUser: anUser
	"Updates an user."
	anUser isUser.
	Users update: anUser.! !

!UserManager methodsFor: 'updating' stamp: 'has 6/27/2013 19:20'!
updateUserWithLogin: aLogin withPassword: aPassword withEmail: anEmail withName: aName isAdmin: anAdminFlag isEnabled: anEnabledFlag
	"Updates an user."
	| anUser |
	anUser := self userWithLogin: aLogin.
	anUser login: aLogin;
			password: aPassword;
			email: anEmail;
			username: aName;
			isAdmin: anAdminFlag;
			isEnabled: anEnabledFlag.
	^self updateUser: anUser.! !

!UserManager methodsFor: 'accessing' stamp: 'oda 5/1/2013 23:50'!
user
	"Returns the users in the UserManager"

	^user! !

!UserManager methodsFor: 'accessing' stamp: 'has 6/24/2013 21:31'!
userWithLogin: aLogin
	"Returns the user with the specified login"
	| anUser |
	anUser := Users searchByLogin: aLogin.
	"anUser ifNil: [self error: 'The login of this user does not exists.']."
	^anUser! !

!UserManager methodsFor: 'creating' stamp: 'oda 6/30/2013 23:17'!
validateUser: anUser
	"I validate a new user so it can be included in database."
	anUser isUser.
	
	OCMSUtilities ifNotAlphanum: anUser login raiseError: 'Invalid login'.

	(anUser username isNil or: [anUser username isEmpty])
		ifTrue: [self error: 'Invalid username.'].
	(anUser email isNil or: [anUser email isEmpty])
		ifTrue: [self error: 'Invalid email.'].
	(anUser password isNil or: [anUser password hash = '' hash])
		ifTrue: [self error: 'Invalid password.'].
	
		
	(self loginExists: anUser login)
		ifTrue: [self error: 'This login is already used'].
	(self emailExists: anUser email)
		ifTrue: [self error: 'This email is already used'].
! !

Object subclass: #UserType
	instanceVariableNames: ''
	classVariableNames: 'UserTypeList'
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!UserType commentStamp: 'oda 5/1/2013 20:25' prior: 0!
UserType class is used to enumerate roles of users, so it can be used to set roles of users within Disciplines.

There are the following roles that can be accessed by class methods:
	student
	professor

UserTypeList is a class variable that contains a set with all roles availables.
!

!UserType class methodsFor: 'accessing' stamp: 'oda 7/1/2013 15:17'!
moderator
	^ #Moderator! !

!UserType class methodsFor: 'instance creation' stamp: 'oda 5/1/2013 18:13'!
new
	self error: 'This class should not be instanciated'! !

!UserType class methodsFor: 'class variables' stamp: 'has 6/30/2013 15:58'!
resetRoles
	"i reset the roles in UserTypeList"
	UserTypeList := nil.! !

!UserType class methodsFor: 'accessing' stamp: 'oda 7/1/2013 15:18'!
student
	^ #Student! !

!UserType class methodsFor: 'class variables' stamp: 'oda 6/26/2013 21:11'!
userTypeList
	UserTypeList ifNil: [UserTypeList := Set new add: UserType moderator; add: UserType student; yourself].
	^ UserTypeList! !

!UserType class methodsFor: 'class variables' stamp: 'has 6/28/2013 14:04'!
validateRole: aRole
	(self userTypeList includes: aRole)
			ifFalse: [self error: 'This is not a valid role: ', aRole].! !
